netapp_ontap.models.uri API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.uri`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class UriSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the Uri object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `fragment GET POST PATCH`

    The fragment field of the uri.

    Example: top

  `host GET POST PATCH`

    The host field of the uri.

    Example: 10.1.1.1

  `path GET POST PATCH`

    The path field of the uri.

    Example: /api/cluster

  `port GET POST PATCH`

    The port field of the uri.

    Example: 433

  `query GET POST PATCH`

    The query field of the uri.

    Example: key1=value1

  `scheme GET POST PATCH`

    The scheme field of the uri.

    Example: https

  `userinfo GET POST PATCH`

    The userinfo field of the uri.

    Example: john.doe